package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!0````!$``6(````#0``,X$```````T`"``
M"0`H`!P`&P````8````T$```-!```#0```$@```!(`````4````$`````P``
M`500``%4$``!5`````T````-````!`````$````!`````!`````0``````!A
M$```81`````%``$```````$``&[P$`%N\!`!;O```%W5``!N&`````8``0``
M`````@``;Q`0`6\0$`%O$````.````#@````!@````0````$```!9!```600
M``%D````1````$0````$````!&1TY5```&"H$`!@J!``8*@````4````%```
M``0````$9'3E40``````````````````````````````!@````1D=.52``!N
M\!`!;O`0`6[P```!$````1`````$`````2]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````#P````0````4`````T=.50"S
M8W'G';+#D5[C$5Z\-8$G(?>VTP```"4```!$````"`````@$$!P`@@1`)0!`
M`#BH`8:B`B`$0"D$*$M',J(X"`P$B@```$0```!%````````````````````
M1P```$D```!*`````````$L```!,````3@```$\```!0````40````````!2
M``````````````!3````5````%<``````````````%@```!:````6P```%T`
M````````7P```&$``````````````&,```!D````9@````!QLM7)+4?>SDG[
MX*,.[]/J:Z/=I[:;Q2^>X\W;@9SYAY:;I%;60PEK'(OR.0N7.@V0!8G%GN(4
M#0[D_R%7$(H+0)RYQ'R:?VIOBP&SFYRI?Q_?Q6X<6''9?)+CN\#C2ZQ\U&35
M"@*GX.W;8C-K2O!Z9LRO9^S514(!QD?CQ8Y!?:EARI0L/^7#'=/;\F!LH?H.
M\8VY`````````````````````````K$``````````!(```````-E````````
M```2```````![@``````````$@```````],``````````!(```````-6````
M```````2```````!!P``````````$@```````LP``````````!(```````"=
M```````````2```````"N```````````$@```````'D``````````!(`````
M``$"```````````2```````":```````````$@```````Q,``````````!(`
M``````)Y```````````2```````!:P``````````$@```````R,`````````
M`!(```````,:```````````2```````!*P``````````$@```````*L`````
M`````!(```````&U```````````2```````!4@``````````$@```````C<`
M`````````!(```````'F```````````2```````"E0``````````$@``````
M`:(``````````!(```````*&```````````2```````!K@``````````$@``
M`````3D``````````!(```````,J```````````2````````$0``````````
M(````````DD``````````!(```````,W```````````2````````0@``````
M````$@```````J,``````````!(```````-L```````````2```````!WP``
M````````$@```````-D``````````!(```````-(```````````2````````
MB```````````$@```````6```````````!(```````*J```````````2````
M```"@```````````$@```````E8``````````!(```````('```````````2
M```````"C@``````````$@```````#0``````````!(```````$,````````
M```2```````"TP``````````$@```````9<``````````!(```````*^````
M```````2````````Y@``````````$@```````UX``````````!(```````*<
M```````````2```````!>0``````````$@```````"```````````"``````
M``"]```````````2```````!20``````````$@```````SX``````````!(`
M``````!1```````````2```````"3@``````````$@```````O0`````````
M`!(```````'S```````````2```````"X0``````````$@```````A@`````
M`````!(```````)?```````````2```````"[```````````$@```````OX`
M`````````!(```````$8$`!98``````2```````$`1``1$0```N\$@``#```
M!$P0`#_X```",!(```P```.J$`!<0``````2```-```#@!`!S,@````$(0``
M&0```[`0`#N$````#!(```P```0Q$`!5>````+02```,````:!``6B``````
M$@```````/<0`<S0````!!$``!D```0.$`%Q%``````0```8```##!`!S,P`
M```$$0``&0``!!`0`7$4`````"```!@```-_$`',R`````0A```9```#H!``
M5BP````$$@``#```!&$0`#N0```"5!(```P```#,$`',U`````$1```9```#
M?A`!S,@````$$0``&0```WD0`!/@```"0!(```P```2`$`!"*````(`2```,
M```#P1``0J@````T$@``#````]P0`%0,````T!(```P```./$`',Q0`````0
M`/_Q```#FQ`!W0@`````$`#_\0```B@0`%R(````!!$```X```2J$`!0````
M!`P2```,```$&Q``.KP```#($@``#```!!00`!8@````)!(```P```&'$`!7
M(``````2```````#]1``/C0```'$$@``#````X@0`<S%`````!``__$```/H
M$``]Y````%`2```,```$CA``5-P```!0$@``#```!$$0`DS%`````!```!@`
M``19$``Z&````$02```,```!P!`!S-@````3$0``&0``!&X0`$+<```!:!(`
M``P```1;$``3B``````2```+`&QI8G!E<FPN<V\N-2XQ-`!?7V=M;VY?<W1A
M<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N
M,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E
M<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`
M7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E
M9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M
M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I
M9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C
M7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD
M`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`7U-$05]"05-%7P!P87)?:6YI
M=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?
M,BXS`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"``(`
M`P`"``(``@`"`````@``````!``"``(````"``(````````````%``8``@``
M``(``@````<````"``(````"``(`!@````0```````(``@`"``,``@``````
M!P````0````"``(````````````(`````@`(``,`"``#``(``@`)`````0`!
M``$``@`!``$```````$``@`!``(``0`!`````@`!``$``0`!``$``0`!``$`
M`0`!`````0`!``$``0`!``$````!``$````!``(```'/````$````#`-:6D2
M````!@``!,`````0#6EI$`````,```3*```````!``8```(>````$``````-
M:6D3````"0``!-0````0#6EI$@````@```3`````$`EI&70````'```$W@``
M`!`):1ER````!0``!.H````0#6EI%`````0```3V````$`UI:1`````"```$
MR@`````0`6_P```>%``````0`<S(``!4$P`````0`<S,``!.$P`````0`<S0
M``!,$P`````0`<S4``!3$P`````0`<S8``!F$P`````0`7`````!%0`````0
M`7`$```"%0`````0`7`(```#%0`````0`7`,```$%0`````0`7`0```%%0``
M```0`7`4```&%0`````0`7`8```'%0`````0`7`<```(%0`````0`7`@``!?
M%0`````0`7`D```)%0`````0`7`H```*%0`````0`7`L```+%0`````0`7`P
M```,%0`````0`7`T```-%0`````0`7`X```.%0`````0`7`\```/%0`````0
M`7!````0%0`````0`7!$```1%0`````0`7!(```2%0`````0`7!,```3%0``
M```0`7!0```4%0`````0`7!4```5%0`````0`7!8```6%0`````0`7!<```7
M%0`````0`7!@```8%0`````0`7!D```9%0`````0`7!H```:%0`````0`7!L
M```;%0`````0`7!P```<%0`````0`7!T```=%0`````0`7!X```>%0`````0
M`7!\```?%0`````0`7"````@%0`````0`7"$```A%0`````0`7"(```B%0``
M```0`7",```C%0`````0`7"0```D%0`````0`7"4```E%0`````0`7"8```F
M%0`````0`7"<```G%0`````0`7"@```H%0`````0`7"D```I%0`````0`7"H
M```J%0`````0`7"L```K%0`````0`7"P``!$%0`````0`7"T```L%0`````0
M`7"X```M%0`````0`7"\```N%0`````0`7#````O%0`````0`7#$```P%0``
M```0`7#(```Q%0`````0`7#,```R%0`````0`7#0```S%0`````0`7#4```T
M%0`````0`7#8```U%0`````0`7#<```V%0`````0`7#@``!+%0`````0`7#D
M```X%0`````0`7#H```Y%0`````0`7#L```Z%0`````0`7#P```[%0`````0
M`7#T```\%0`````0`7#X```]%0`````0`7#\```^%0`````0`7$````_%0``
M```0`7$$``!`%0`````0`7$(``!!%0`````0`7$,``!"%0`````0`7$0``!#
M%0````"4(?_P?`@"II`!`!23P0`(0I\`!7_(`J8_W@`!.]Y<6(`>__PO@```
M09X`"$@`1,U(``-12`!"=8`!`!1\"`.F@\$`"#@A`!!.@``@````````````
M````E"'_T'P(`J:080`<.&$`')"!`!@X@0`8D*$`%#BA`!20`0`TD\$`*)/A
M`"Q(`$2E/(`0`#Q@$``XA%E@.&-:('R%(W@_X!`"2`!!!3T@$`*+R<S4+YX`
M`$">`"A(`$.E/2`0`B^#``"0:=T$09X!S$@`0O&`?\S02`!&.9O#!-R`?\S0
M2`!&+8@#!1]\:1MX@'_,T&````*8"04?2`!&%8%A`!R)(P4?.`L`!6$I``&9
M(P4?/2!#,)$A``@](!``D`$`#,`)7/P](!``R:$`"/VM`"C("5T`/2`0`/VM
M`"K("5T(_XT``$&=`3A4`Q`Z/^`0`D@`0UV!00`8/6`0`#O_S/2`H0`<?&D;
M>(`*```OA0`!D'\0")`#```X"V`P/6`0`3EK<2"0`P`$.`L`!#U@$`"0`P`(
M.`M@-)`#``PX```$D!\0!$"=`!PX!?__.6,`#'P)`Z:$"@`$E`L`!$(`__@X
MI0`#.6```(!_$!!4H!`Z/(`0`'UI`2XXA#I<?29+>#C@``!(`$19?'X;>4&"
M`$R`?Q`02`!"&3Q@$``X8UW@3,8Q@D@`'/$O@P``09X`/(!_$!!(`$&Y2`!#
M]8`!`#1_P_-X@\$`*'P(`Z:#X0`L."$`,$Z``""`?Q`02`!$@7Q^&WA+__^L
M@'\0#"^#``!!G@`,2``^-4O__[@\8!``.&-=?$S&,8)(`!R-+X,``)!_$`Q!
MGO^<2___W#Q@$``\@!`".&-?!#B$S-A,QC&"2`!"_3A@``%(`$)U?"D+>%0A
M`#8X````E"'_\'P(`Z:0`0``/0`0`(6H7'A(`$*0E"'_X'P(`J:3@0`0/X`0
M`I`!`"2(',SLDZ$`%"^```"3P0`8D^$`'$">`&`_H!`!/\`0`3N];O@[WF[\
M/^`0`G_=\%"!/\SP?]X6<#O>__]_B?!`0)P`+#O_S/`Y*0`!52`0.I$_``!\
M'0`N?`D#IDZ`!"&!/P``?XGP0$&<_^`X```!F!S,[(`!`"2#@0`0?`@#IH.A
M`!2#P0`8@^$`'#@A`"!.@``@E"'_\'P(`J:0`0`4@`$`%#@A`!!\"`.F3H``
M('P(`J:4(?_P/&`0`9`!`!2``V\`.&-O`"^```!!G@`</2```#@)```O@```
M09X`#'P)`Z9.@`0A@`$`%#@A`!!\"`.F3H``()0A__!\"`*FD`$`%(`!`!0X
M(0`0?`@#IDZ``""4(?Q0?&P;>#EC`#@X8``(.````'QI`Z:1P0-H.2$`X)'A
M`VR2`0-PDB$#=))!`WB280-\DH$#@)*A`X22P0.(DN$#C),!`Y"3(0.4DT$#
MF)-A`YR3@0.@DZ$#I)/!`ZB3X0.L@0L``(%+``0Y:P`(D0D`!)`)``"0"0`(
MD4D`##DI`!!"`/_@.(``0#DA`4!\B0.F.*```#DI``B!"?_8@4G_W(%I``"`
M"0`$@,G_J'T+6GB`Z?^L?4`">($)_YA\RUIX@4G_G'S@`GA]"UIXD*D`&'U`
M`GA5:P@\5``(/GP`6WB0"0`<0@#_L(%!`.`\H%J".\```(%A`.1@I7F9.T``
M`(#,`"!_4M-X@.P`)(.!`.B#H0#L?6LX%'U*,12!#``8?493>($L`!Q\ZRH4
M@HP`#'P+.!!\``$0@JP``'^]2!1_G$$4@@$`\%:)\#Z"(0#T5JHH-'P``-""
MS``(?,`R%(*,`!""K``45LOP`G^6XWB"[``$?3M;>'XQJ!1^$*$4@&P`%(*L
M``Q6ZR@^@PP`''U_4WA^_2H4?&NH.(,L`!!]Y_@4?<;Q%'\`J'B"K```@\P`
M!'T]N!!]*4D0?_$J%("!`/Q_2J@X?RBH>']G\#B#@0#X?&;P>'P36WB`80$$
M?51#>%:K\`)7RO`^?2D`T'P/FA1]65MX?Z0J%'UQ^!!]:UD0?LFR%'SU,WA_
M:`!X?K6X%'Z4L11\!\@X@H$!`'U$Z!!]2E$0@($!#%0)*#Y^'H-X?6L`T'TU
M2A14%_`^?J,J%'T3.WA_R_(4?4H`T'THN#@[````?6.H$'UK61!__Y@4?]Z1
M%(!A`115+R@^?XKB%'\J2'A\'WH452?P/G_]V!1_W-$4@T$!"']D*A1]44-X
M?Q##>'UK`-!^,?@4?A#Q%'P(.#@ZP```?438$'U*41"`@0$<?HNB%%0)*#Y^
MZP!X?3%*%'YUR!1^5,$4@P$!$'\C*A14'_`^?7U#>'[<LWA]2@#0?G/H%'Y2
MX11]*/@X?6/($'UK61"`80$D53$H/CC```!_2M(4?.I(>'P3BA1_>[@4?UJQ
M%%4]\#Z"P0$8?N0J%'U50WA\U#-X?6L`T'ZUV!1^E-$4?`CH.'U$N!!]2E$0
M?PO"%("!`2Q_ZP!X.\```%0)*#Y]-4H4?.?(%'S&P12#`0$@?R,J%%0;\#Y]
M<T-X?]+S>'U*`-!^<S@4?E(Q%'THV#A]8\@0?6M9$(!A`315,2@^?LJR%#N`
M``!_JDAX?!.*%'__N!1_WK$452?P/H+!`2A^Y"H4?55#>'^4XWA]:P#0?K7X
M%'Z4\11\"#@X?42X$'U*41!_"\(4@($!/']K`'@[0```5`DH/GTU2A1_O<@4
M?YS!%(,!`3!_(RH45!_P/GUS0WA_4M-X?4H`T'YSZ!1^4N$4?2CX.'UCR!!]
M:UD0@&$!1%4Q*#Y^RK(4.,```'SJ2'A\$XH4?WNX%']:L115/?`^@L$!.'[D
M*A1]54-X?-0S>'UK`-!^M=@4?I31%'P(Z#A]1+@0?4I1$'\+PA2`@0%,?^L`
M>#O```!4"2@^?35*%'SGR!1\QL$4@P$!0'\C*A14&_`^?7-#>'_2\WA]2@#0
M?G,X%'Y2,11]*-@X?6/($'UK61"`80%453$H/G[*LA0[@```?ZI(>'P3BA1_
M_[@4?]ZQ%%4G\#Z"P0%(?N0J%'U50WA_E.-X?6L`T'ZU^!1^E/$4?`@X.'U$
MN!!]2E$0?PO"%("!`5Q_:P!X.T```%0)*#Y]-4H4?[W(%'^<P12#`0%0?R,J
M%%0?\#Y]<T-X?U+3>'U*`-!^<^@4?E+A%'TH^#A]8\@0?6M9$(!A`615,2@^
M?LJR%#C```!\ZDAX?!.*%%4]\#Y_>[@4?UJQ%(+!`5A^Y"H4?55#>'S4,WA]
M:P#0?K78%'Z4T11\".@X?42X$'U*41!_"\(4@($!;'_K`'@[P```5`DH/GTU
M2A14&_`^?.?(%'S&P11]<T-X@P$!8'\C*A1_TO-X?4H`T'YS.!1^4C$4?2C8
M.#N```!]8\@0?6M9$%4Q*#Z`80%T?LJR%'^J2'A\$XH4?_^X%'_>L115)_`^
M@L$!:'[D*A1]54-X?Y3C>'UK`-!^M?@4?I3Q%(*!`7A\"#@X.T```'U$N!!]
M2E$0@($!?%0)*#Y_"\(4?VL`>'TU2A1_.>@4?QCA%(.!`7!_HRH45!_P/GUS
M0WA_4M-X?4H`T'YSR!1^4L$4?.M(>()!`8!]`^@0?0A!$(!A`815-2@^.,``
M`'[*LA1]*O@X?!.J%'[WV!1^UM$4?J0J%(-!`8Q5.?`^?7%3>'S0,WA]"`#0
M?C&X%'X0L11_Z@!X?62H$'UK61!4$R@^@($!B'^(XA0[P```?`C(.#]@;ME]
M,9H48WOKH7SGZ!1\QN$45!?P/GU/0WA_SO-X@0$!E'UK`-!^8]H4?>\X%'W.
M,11]*K@X?HNB%#L```!_*TAX524H/E4G\#Y]?5-X?2\J%'P#F!!\``$0?QS#
M>(!A`9Q__Z@4?]ZA%'RZVA1__^@4?][A%%4Q*#Z#P0&0?```T#C```!\ZKIX
M?7HH$'UK61!^0)(4@T$"#'P?BA0ZP```?^C:%'\YF!1_&)$453WP/GS4LGA]
M54IX?6L`T'TH^!!]*4D0?K7(%'Z4P12!`0&D?ZHZ>#N```!4$2@^?(LB%'TI
M`-!^]R@4?M8A%("!`9A\H]H45!GP/GUUBA1_DC)X?5,">'_)\A1^<[@4?E*Q
M%'__.!1_WC$4@,$!H'SHVA1_*NIX.P```'P#*!!\``$057$H/H!A`:Q5=_`^
M?3.*%'\4XGA]55IX?```T'UH.!!]:UD0?K7X%'Z4\12!`0&T?NK*>#K```!5
M,2@^?(`B%'UK`-!_O2@4?YPA%("!`:A\H]H453_P/GP5BA1^TL)X?5-*>'S+
M,A1^<^@4?E+A%'\Y.!1_&#$4@,$!L'SHVA1_ZKIX.\```'TC*!!]*4D05!$H
M/H!A`;Q4'?`^?7.*%'_4LGA]50)X?2D`T'P(.!!\``$0?K7(%'Z4P12!`0'$
M?ZKZ>#N```!5<2@^?(DB%'P``-!^]R@4?M8A%("!`;A\H]H457GP/GTUBA1_
MDO)X?5-:>'S`,A1^<[@4?E*Q%'__.!1_WC$4@,$!P'SHVA1_*NIX.P```'UC
M*!!]:UD053$H/H!A`<Q5-_`^?!.*%'\4XGA]54IX?6L`T'TH.!!]*4D0?K7X
M%'Z4\12!`0'4?NK*>#K```!4$2@^?(LB%'TI`-!_O2@4?YPA%("!`<A\H]H4
M5!_P/GUUBA1^TL)X?5,">'S),A1^<^@4?E+A%'\Y.!1_&#$4@,$!T'SHVA1_
MZKIX.\```'P#*!!\``$057$H/H!A`=Q5??`^?3.*%'_4LGA]55IX?```T'UH
M.!!]:UD0?K7(%'Z4P12!`0'D?ZKZ>#N```!5,2@^?(`B%'UK`-!^]R@4?M8A
M%("!`=A\H]H453GP/GP5BA1_DO)X?5-*>'S+,A1^<[@4?E*Q%'\JZG@[````
M?2,H$'TI21"`80'L5!$H/G__.!1_WC$4?.C:%(#!`>!4%_`^?Q3B>'USBA1]
M50)X?2D`T'P(.!!\``$0?_^H%'_>H12!`0'T@\$!Z#K```!^ZLIX57$H/GR)
M(A1\``#0577P/GT_BA1^TL)X?^/:%'U36GA_O2@4?YPA%'S`,A1_O9@4?YR1
M%#J```!^JKIX?6/X$'UK61"`80'\53$H/G\Y.!1_&#$4?.C:%(#!`?!5,_`^
M?H2R>'P=BA1]14IX?6L`T'TH.!!]*4D0.D```($!`@1_.2@4?Q@A%'YJJGA4
M!?`^5!$H/G_+\A1]*0#0?7F*%#B```!_/[@4?QZQ%'Y<HGB#P0'X?^/:%'U=
M`GA\R3(4?*J:>'^]R!1_G,$4?.>H%'S&H11\`_@0?``!$%5Q*#Y\EI)X?5=:
M>'T]BA1^]S@4?M8Q%(#!`@!5>?`^?.C:%'P``-!_(RIX.P```%4K*#Y_P/(4
M?`@X$'P``1!_'")X?1=:%'Q]2GA]?Y@4?5Z1%'P``-!5/_`^?[U8%'^<410[
MP```50LH/GS`,A0Y(```?^#*>'SG*!1\QB$4?\K">("A`A21(0`8?3U:%'P+
M0GB`@0(<.L```'^G6!1_AE$4?7K:%(%!`@A\&E@0?``!$(+A`B1\``#0DL$`
MF%4'\#Y]0%(4@L$"('\Y6!1_&%$4.,```'S@^GA5*R@^?,KR>'T=6A1\"TIX
M?[E8%'^8411]9=H4@4$"$'P%6!!\``$0?```T%4Y\#Y]0%(4?_]8%'_>411_
M(#IX.P```%4+*#XY0```?3U:%)%!`)!\"T)X?PHR>#M```!_OU@4?YY1%'UD
MVA2!00(8?`18$'P``1"300"(?```T'U`4A15'_`^?*LX%'R*,115*R@^?/U:
M%#O```!_X,IX/Z"/&SN```!CO;S<?\K">'P+2G@Z@```?V58%']$411]?;@4
M?5RQ%(-!`IB2@0"@?SE8%'\8412!00*(527P/H%A`HQ\H/MX.(```'RC^#A]
M/5@4?1Q1%(%!`I!\X``X@6$"E#J```"1`0#(.D```#G```!^_5@4?MQ1%($!
M`BA4ZR@^D2$`S'S;6A2!(0(L.@```(-A`IQ]?4@4?5Q!%)+!`-!4Z?`^DN$`
MU'[]V!1^W-$4?VOX%']*\12#X0(T?(KP.(/!`C!\"QMX?2`K>)+!`-A_.5@4
M?QA1%%3+*#Z2X0#<?/E:%(,!`H!]??@4?5SQ%#D```"#(0*$?2,H.'S``#@Z
MP```.N```'_K*!1_RB$4DL$`J%3%\#Z"P0(X?0H@.'P+&WB2X0"`@N$"/'][
M6!1_6E$4?*!+>%3K*#Y\VUH4.(```']]R!1_7,$4?7VX%'U<L12300#`?*-(
M.'S@`#B380#$?VM(%']*012#`0)`5.GP/GR*0#B#(0)$?`L;>'T@*WA__U@4
M?]Y1%%3+*#Y\_UH4.0```'U]R!1]7,$4?2,H.'S``#@[P```D\$`>'_K*!1_
MRB$4?0H@.'P+&WA_>U@4?UI1%%3K*#Z#00)X5,7P/GS;6A2#80)\?*!+>#B`
M``!\HT@X?7W8%'U<T12#00)(?.``.(-A`DP[````D4$`N#K```"180"\?7W8
M%'U<T11_:T@4?TI!%'R*0#A\"QMX5.GP/G__6!1_WE$45,LH/H/!`E!\_UH4
M@^$"5'T@*W@Y0```.0```'TC*#B100!P?,``.'U]^!1]7/$4?^LH%'_*(11]
M"B`XD\$`*'P+&WB3X0`L5,7P/G_[6!1_VE$4@T$"<'R@2WB#80)T?.,`.(/!
M`E@X@```?7W8%'U<T12080!L?*-(.)%A`+14ZR@^?-]:%(/A`EP[0```D4$`
ML'U]^!1]7/$4?^M(%'_*0123X0!D?(I`.(/A`&R3P0!@?^L;>(/!`"B#X0`L
M?3]8%'T>4114__`^5,LH/CC@``!_X"MXD.$`"'SI6A0[P```5.@H/H$A`F1_
MXR@XD0$`#'S``#A4^_`^@0$"8'U]2!1]7$$4?2LH%'T*(11_RB`X@($`9'P+
M&WB`80!@D2$`+%3)\#Y]:R`4?4H9%("!``Q](/MX?.8`.)$!`"A]:R(4?2KX
M.%5E*#Y5>?`^D*$`=']@2W@Y````@*$`P'U@`#B0P0!@@,$`Q(#A`FQ\AL@4
M?&7!%(#!`FB100!L?7TX%'U<,12`P0"P@.$`M'UK^!1]2O$4D&$`P']C2#B0
M@0#$?`,;>'RG2!1\AD$4?T=`.)!A`"20X0`@?R#;>)"A`+2`P0`D@*$`()"!
M`+"`X0!@?(LP%'QJ*11]!O`X@0$`;)#!`!!\YT-XD($`))#A`!2#P0`H@^$`
M+("!`!2080`@@&$`$(#!`"1]?R`4?5X9%("!`'2`X0#4?2LB%%4E*#Y5-_`^
M?68J%(#!`-!](P`X577P/E5H*#Z0H0!\?^>H%'_&H121`0"$?N#+>(#A`+A]
M8``X@0$`O'[IR#A_)=@X?`E+>'QE*WA]:-@4?4?1%'[(P#B1`0`XD2$`/(#!
M`#B0H0`T?H6P.(#A`#R#(0"T?2LX%'T*,11_!]`X@V$`-)#A`#"#`0"PD*$`
M0(-!`#"`80#(?7G8%'U8T12#80"$@P$`P'T+VA2#(0#$50`H/H-!`$!5$_`^
M?.D"%)`!`(Q^H+MX?0``.'ZIN#A\"4MX5.0H/I$A`$1^::@X5/'P/I"!`)2#
M80!$?7G8%'U8T11\RR(4@($`S%3`*#Y4S_`^D`$`G'Y@JWA]9+@4?4.Q%'S@
M`#B"H0#<?D2@.'P)2WB"@0#8D($`2'W@BWA^%I`XD2$`3'\UF!1_%)$4?=6`
M.)*A`%@X@```@.$`2($!`$R2P0!0?6M`%'U*.12!`0"<?2M"%'WKB#A](``X
M52HH/GP+6WA^()MXD4$`I'S&`#A^()@XD6$`7%4I\#Y\P`-XD2$`''TW2WA]
M(WMXD`$`5'[TNWB#00!0@V$`5(+!`!A]?]@4?5[1%(-A`*2!00*@?MIP.'P+
MVA2!80*D@\$`6%0%\#Z#X0!<?/U8%'S<411^ZW@X@D$"L'TY^!1]&/$4?R>(
M%'\&@12`P0*H@.$"K%0?*#Y\`!@X@0$`&'P;6WA]*?H4D^$`K'R@NWA5/_`^
M@F$"M'\YV!1_&-$4?*N@.(*!`!A_?3@4?UPQ%((!`KA5-R@^@B$"O'TI`#A\
MAD`X?!FZ%'TG6WA^^W@4?MIQ%'_I*WB!P0+`?O<X%'[6,12!X0+$5!4H/E0;
M\#Y\"4@X?!>J%(*A`!P[P```?/V8%'S<D11_ZR@X?.>H%'S&H11_V"`X?3E;
M>']I^WA^9\@4?D;!%']K^#A_/8@4?QR!%((!`L@[0```@B$"S'P)2#@\X,IB
M.,```&#GP=94'?`^?*7(%'R$P11_5O`X?3=;>%05*#Y\$ZH4?O<H%'[6(11_
MJ-IX?*=X%'R&<10[@```@<$"T'^*TGB!X0+45!GP/GRE^!1\A/$4?0L">($,
M`"!4"2@^?F58%'Y$411]-TH4?*>(%'R&@11_*^IX@@$"V#L```""(0+<?WLH
M%']:(11_%N)X53_P/GUW2GA5-2@^?!.J%'_KRGA^N[@4?IJQ%#O```!^YW@4
M?L9Q%('!`N!_O;@4?YRQ%('A`N1_Q,)X5!OP/GUE`GA4"2@^?GTH%'Y<(11]
M-4H4?*>(%'R&@11_:_IX@@$"Z#M```""(0+L?SDH%'\8(11_5O)X53WP/GUW
M2GA5-2@^?!.J%'^KVGA^N;@4?IBQ%#N```!^YW@4?L9Q%('!`O!__[@4?]ZQ
M%('A`O1_A-)X5!GP/GUE`GA4"2@^?G\H%'Y>(11]-4H4?*>(%'R&@11_*^IX
M@@$"^#L```""(0+\?WLH%']:(11_%N)X53_P/GUW2GA5-2@^?!.J%'_KRGA^
MN[@4?IJQ%#O```!^YW@4?L9Q%('!`P!_O;@4?YRQ%('A`P1_Q,)X5!OP/GUE
M`GA4"2@^?GTH%'Y<(11]-4H4?*>(%'R&@11_:_IX@@$#"#M```""(0,,?SDH
M%'\8(11_5O)X53WP/GUW2GA5-2@^?!.J%'^KVGA^N;@4?IBQ%#N```!^YW@4
M?L9Q%('!`Q!__[@4?]ZQ%('A`Q1_A-)X5!GP/GUE`GA4"2@^?G\H%'Y>(11]
M-4H4?*>(%'R&@11_*^IX@@$#&#L```""(0,<?WLH%']:(11_%N)X53_P/GUW
M2GA5-2@^?!.J%'_KRGA^N[@4?IJQ%#O```!^YW@4?L9Q%('!`R!_O;@4?YRQ
M%('A`R1_Q,)X5!OP/GUE`GA4"2@^?GTH%'Y<(11]-4H4?*>(%'R&@11_:_IX
M@@$#*#M```""(0,L?SDH%'\8(11_5O)X53WP/GUW2GA5-2@^?!.J%'^KVGA^
MN;@4?IBQ%#N```!^YW@4?L9Q%('!`S!__[@4?]ZQ%('A`S1_A-)X5!GP/GUE
M`GA4"2@^?G\H%'Y>(11]-4H4?*>(%'R&@11_*^IX@@$#.#L```""(0,\53_P
M/G][*!1_6B$4?Q;B>'UW2GA5-2@^?!.J%#O```!^N[@4?IJQ%'_KRGA^YW@4
M?L9Q%('!`T!_O;@4?YRQ%('A`T1_Q,)X5!OP/GUE`GA4"2@^?GTH%'Y<(11]
M-4H4?*>(%'R&@11_:_IX@@$#4#M```""(0-453WP/G\Y*!1_&"$4?U;R>'UW
M2GA5-2@^?!.J%#N```!^N;@4?IBQ%'^KVGB"@0-8?N=X%'[&<11^]_@4?M;Q
M%'^$TGA]90)X5`DH/GYW*!1^5B$4@L$#2%09\#Z"X0-,?35*%#L```!_*^IX
M?*>X%'R&L115-2@^?!.J%(*A`UQ_'N)X53?P/GU_2GA_>R@4?UHA%'[KRG@Z
MP```?WOX%']:\114"2@^?^>(%'_&@11].TH4?__H%'_>X11^Q,)X?64">%0=
M\#Y_?R@4?UXA%%4K*#Z#3``,?+M:%'^@NGA]9Z@4?4:A%#N````X@```?.O(
M%'S*P12##```?YZR>(,L``1\'TIX5*LH/E2`*#1__S@4?]XQ%(/,`!A]>P-X
M?7_:%#E```"#;``4?6O(%'U*P12#+``(52?P/H/L`!PXP```?*70%'R$R12!
M+``D.````(-,`!!_O?@4?YSQ%'[W2!1^UD$4D`P``'SGV!1\QM$4D6P`!)`,
M``B0K``,D`P`$)#L`!20#``8DZP`')`,`""2[``D@<$#:('A`VR"`0-P@B$#
M=()!`WB"80-\@H$#@(*A`X2"P0.(@N$#C(,!`Y"#(0.4@T$#F(-A`YR#@0.@
M@Z$#I(/!`ZB#X0.L."$#L$Z``""4(?_0?`@"II.!`"!\?!MY.&```)-!`!A\
MFB-XD`$`-)-A`!R3H0`DD\$`*)/A`"Q!@@"8/2`0`H-IS,@OFP``09X`B(@<
M```[H```+X```$&>`#`O@``]09X`*'^)XWA_G>-XC`D``3N]``$O@```+P``
M/4&>``A`FO_L?[SH4(/[```X8```+Y\``$&>`#Q_?MMX?^/[>'^$XWA_I>MX
M2``HA2^#``!`G@`0?!_HKB^``#U!G@`\A_X`!"^?``!`GO_4.&```(`!`#2#
M00`8?`@#IH-A`!R#@0`@@Z$`)(/!`"B#X0`L."$`,$Z``"!_V_!0.'T``7_>
M%G!\?QH4D]H``(`!`#2#00`8?`@#IH-A`!R#@0`@@Z$`)(/!`"B#X0`L."$`
M,$Z``""4(?_@?`@"ICB!`!R0`0`D3,8Q@DO__L&``0`D."$`('P(`Z9.@``@
ME"'_T'P(`J:0`0`TD\$`*#_`$`*3X0`L?'\;>'_C^W@X@0`<3,8Q@DO__H4O
M@P``09X`4(`!`!R!?LS(5``0.GTK`A2!20`$+XH``'U+`2Y!OO_,.2D`!(0)
M``0O@```D`G__$">__1_X_MX.($`'$S&,8)+__XY+X,``$">_[B``0`T@\$`
M*'P(`Z:#X0`L."$`,$Z``""4(?_@?`@"II/A`!P_X!`"@'_,T)`!`"23H0`4
MD\$`&$@`)SF!(P&$@'_,T(/)``1(`"<IBZ,$U(!_S-!7O09^2``G&8$C``2`
M"0`05`"$,'^]`WBSO@`"@'_,T$@`)OV!(P&$@'_,T(/)``1(`";M/(`0`#B@
M```XA&`L2``E/9!^`!R`?\S02``FT8$C`82`?\S0@\D`!$@`)L&``P74@'_,
MT)`>`"!(`":Q@2,!A(!_S-"#R0`$2``FH3@```"!(P@$+XD``$&>`!2`?\S0
M2``FB8$C"`2`"0!PD!X`)#O```"`?\S02``F<8$C`82`?\S0@2D`!)/)`"A(
M`"9=@2,!A(!_S-"!*0`$D\D`&$@`)DF!(P&$@'_,T(/I``1(`"8Y@`,!C)`?
M`"R``0`D@Z$`%'P(`Z:#P0`8@^$`'#@A`"!.@``@E"'_8'P(`J:3X0"<?'\;
M>9`!`*2380",DX$`D).A`)23P0"808(`$(@?```O@```0)X`*(`!`*2#80",
M?`@#IH.!`)"#H0"4@\$`F(/A`)PX(0"@3H``($@`)?E\?AMY0:+_U#^`$``[
MG%T0?\/S>$@`)6%\:1MY?^/[>#MI`!-!@@"<B`D`$R^``"Y!G@#$2``CL7Q]
M&WA_8]MX2``CI7Q]&A0X8P`"2``C*7^&XWA_Y_MX?'T;>']HVW@X@``!.*#_
M_TS&,8)(`".Y?Z3K>#BA`!@X8``#2``E*2^#__]_H^MX09X`%(`!`"A4``0F
M+X!``$&>`(!(`"()?Z/K>$@`(7%_P_-X2``DR7QI&WE_X_MX.VD`$T""_VQ_
MP_-X2``E(7_C^WA(`"&)@`$`I(-A`(Q\"`.F@X$`D(.A`)2#P0"8@^$`G#@A
M`*!.@``@B`D`%"^```!!GO\4+X``+D"^_S"("0`5+X```$&>_P!+__\@2__^
MC4O__X24(?_@?`@"II/A`!P_X!`"D\$`&'Q^&WB`?\S0D`$`)).A`!1(`"1Q
M?\3S>#N@```XHP!@.&```T@`)&TO@P``09X`)(`!`"1_H^MX@Z$`%'P(`Z:#
MP0`8@^$`'#@A`"!.@``@@'_,T$@`)"V``P!P5``$)B^`0`!!G@`@@'_,T$@`
M)!6!(P!P52D$)FT@__\O@*``0)[_L'_#\W@X@``"2``C58`!`"1\?0`T@\$`
M&'P(`Z97O=E^@^$`''^CZWB#H0`4."$`($Z``""4(?_`?`@"II.!`#"3H0`T
MD\$`.)/A`#Q\?QMXD`$`1),!`""3(0`DDT$`*)-A`"R(!```:!T`/2.]``!_
MI`&4?Z/K>$@`(;4X@0`<?'P;>'_C^WA,QC&"2__Z+7Q^&WE!@@%,2``AE3O>
M__\Y/?__?YP80$"=`12#00`</V`0`E=:$#J('P``.2```"^```!!G@`T+X``
M/4&>`"Q_Z_MX?^G[>$@```A!F@`8C`L``3DI``$O@```+P``/4">_^Q]/TA0
M.'P``H/;S,A\8TH42``@N3@`__\O@P``?'[1+D&>`'2('P``/2`0`H%IS,@O
M@```@2$`'%4I$#I]*T@NF`D``$&>`#`O@``]09X`*'TK2WA(```(09H`'(P?
M``$Y*0`!+X```"\``#V<"P`!0)[_Z#@``#T[O?__F`D``(P=``$O@```G`D`
M`4">__0X````?`,#>(`!`$2#`0`@?`@#IH,A`"2#00`H@V$`+(.!`#"#H0`T
M@\$`.(/A`#PX(0!`3H``((P)``$O@```G!X``4&^_[R,"0`!+X```)P>``%`
MGO_D2___J#]@$`(X@``(@QO,R#O```"`&```+X```$&>`"!_"<-XA`D`!#O>
M``$O@```0)[_]#B>``)4A!`Z/2`0`H`)S/0O@```09X`/'\#PWA7VA`Z2``?
M?3@`__\O@P``?'D;>)![S,A!OO]$.!X``3D@``!4`!`Z?3D!+I/!`!Q+__Y<
M.````7R#(WB0"<ST2``?43@`__]\>1MY0:+_$%?:$#I_!,-X?T73>$@`'<63
M.\S(2___N)0A[]!\"`*F.*`/_Y.A$"1\G2-X.($`')/!$"A\?AMX/&`0`)`!
M$#0X8UT8D^$0+(`"C_B0`1`<.````$@`'DTL`P``0($`C#@!$"`[X___?2#Z
M%(@)[_PO@```09X`;'Q_&W@X80`<.(``+W_E^WA(`!_I+X,``$&>`%@](!`"
M@&G,T$@`(.5_Q/-X.*$`''_F^WA(`"!U@2$0'(`"C_A]*0)Y.````$""`$2`
M`1`T@Z$0)'P(`Z:#P1`H@^$0+#@A$#!.@``@+Y\``$">_Y@](!`"@&G,T$@`
M()%_Q/-X?Z7K>$@`';5+__^P2``=390A__!\"`*F/2`0`H!IS-"0`0`42``@
M93R`$``\H!``/,`0`#B$72@XI5<@.,9=1$@`'MF``0`4."$`$'P(`Z9.@``@
ME"'_X'P(`J:3X0`</^`0`H!_S-"0`0`D2``@'4O__Z&`?\S02``@$3S`$``\
M@!``.,9@+#R@$``XA%U0.*50`'S',W@Y````2``?/8`!`"2#X0`<."$`('P(
M`Z9.@``@E"'?T'P(`J:3X2`L.^```)`!(#23P2`H@`*/^)`!(!PX````2``=
M03S`$``]`!``?&<;>#B```$X80`4.*`0`3C&76@Y"%UT3,8Q@D@`'?DO@P``
M09P`0#AA`!0X@1`8.*`0`$@`')%\?AMY08``*#A^``%(`!TA?'\;>4&"`!@X
M@1`8?\7S>$@`&[TX````?!_QKH$A(!R``H_X?2D">3@```!_X_MX0((`'(`!
M(#2#P2`H?`@#IH/A("PX(2`P3H``($@`&^&4(?_P."$`$$O__S"4(>^P?`@"
MIGV``":3H1!$D\$02'Q^&W@\8!``D^$03#AC77Q\GR-XD8$0()`!$%22H1`D
MDL$0*)+A$"R3`1`PDR$0-)-!$#B381`\DX$00(`"C_B0`1`<.````$S&,8)+
M__:).(``+WQ]&WA_P_-X2``<H2^#``!!G@!T/&`0`'_$\W@X8UV(3,8Q@DO_
M^JV!(1`<@`*/^'TI`GDX````?\/S>$""`:R``1!4@8$0('P(`Z:"H1`D@L$0
M*'V`@2""X1`L@P$0,(,A$#2#01`X@V$0/(.!$$"#H1!$@\$02(/A$$PX(1!0
M3H``('_#\W@_8!``2``</3M[79A\>AMX?V3;>'_C^WA(`!UI?'4;>4&B_VPN
M'0``/P`0`#\@$``ZP```/N`0`#L879P[.5VD/X`0`F+6@``[X```B!4``"^`
M``!`G@`(.K==>$&2`!A_H^MX?J2K>$@`&<DO@P``09X`H'ZCJWA(`!O)?34:
M%(@)__\O@``O0)X`&)_I__\X8___B`G__R^``"]!GO_P.&,``7QCTA0O@P__
M0;W^X#B```$XH!``?P;#>'ZGJWA_*,MX?\GS>#AA`!Q,QC&"2``;L8!\S-!(
M`!TY.($`'#BC`&`X8``#2``=&2^#``!`G@`<@'S,T$@`'1F``P!P5``$)G^`
ML`!!G@`@.&```']DVWA(`!QM+X,``'QU&WA`GO\L2__^:#AA`!PX@``!2``<
M02^#``!`GO_4/&`0`#B!`!PX8UV(3,8Q@DO_^/TX80`<2``;?7Q^&WA+__Y$
M2``9@90A__"(`P``+X```$&>`#PY(P`!?&L;>$@``!2,"P`!.2D``2^```!!
MG@`@+X``+T">_^R,"P`!?2-+>#DI``$O@```0)[_Z#@A`!!.@``@E"'_X'P(
M`J:3P0`8?'X;>9`!`"23X0`<08(`Y(@>```O@```09X`V$@`&F4X8___?+X:
M%'\>*$!_A?``0)@`.'P>&*XO@``O0)X`Y'P>*%!\J2MX?`D#ID@``!","?__
M+X``+T">`,@XI?__?X7P`$(`_^Q!G@#X.`7__WRI*WA_G@!`?!XH4'P)`Z9!
MG0$@+Y[__T&>`1@XI?__0D``$(P)__\O@``O09[_\'R^*%`X8```.`4``BN`
M$`!!G0`H/^`0`G_$\W@[_\ST.*4``3O_``0XP!``?^/[>$@`&J%_X_MX@`$`
M)(/!`!A\"`.F@^$`'#@A`"!.@``@.&```D@`&1TL`P``0:+_W#@`+@"P`P``
M@`$`)(/!`!A\"`.F@^$`'#@A`"!.@``@.`7__WRI*WA_G@!`?!XH4'P)`Z9!
MG0!X+Y[__T"^`!1(``!LC`G__R^``"]!G@`,.*7__T(`__!_A?``2___#(@%
M```O@``O09X`%#Q@$``X8UVD2``9G4O__V`X8``"2``8D7QI&WDX8```0:+_
M3#@`+@!](TMXL`D``$O__SPX```!?`D#IDO__N0X```!?`D#IDO__YR4(?^P
M?`@"ICR`$``XH``B.(1<C).!`$`X80`8/X`0`).A`$0_H!``.YQ=^)/!`$@[
MO5U\/\`0`)/A`$P_X!``.]Y=[)`!`%0[_UW0@`*/^)`!`#PX````2``6L3Q@
M$``X8UVH3,8Q@DO_\D$\8!``.&-=M$S&,8)+__(Q/&`0`#AC7;Q,QC&"2__R
M(3Q@$``X8UW(3,8Q@DO_\A%_X_MX3,8Q@DO_\@4\8!``.&-=X$S&,8)+__'U
M?Z/K>$S&,8)+__'I?\/S>$S&,8)+__'=?X/C>$S&,8)+__'1/&`0`#AC7@1,
MQC&"2__QP3Q@$``X8UV(3,8Q@DO_\;$\8!``.&->$$S&,8)+__&A/&`0`#AC
M7AQ,QC&"2__QD3Q@$``X8UXH3,8Q@DO_\5E\9!MY08(`$'^#XWA,QC&"2__U
ME3Q@$``X8UX\3,8Q@DO_\35\9!MY08(`%#Q@$``X8UY03,8Q@DO_]6T\8!``
M.&->7$S&,8)+__$-?&0;>4&"`%A_H^MX3,8Q@DO_]4D\@!``?^/[>#B$7HQ,
MQC&"2__U-8$A`#R``H_X?2D">3@```!`@@!\@`$`5(.!`$!\"`.F@Z$`1(/!
M`$B#X0!,."$`4$Z``"`\8!``.&->;$S&,8)+__"A?&0;>4&"`!1_P_-X3,8Q
M@DO_]-U+__^4/(`0`#AA`"DXA%Z`.*``"D@`&&TO@P``0)[_>'_#\W@X@0`S
M3,8Q@DO_]*U+__]D2``5/90A_^!\"`*FD^$`'#_@$`&`?W$@D`$`)"^#__]!
MG@`8@`$`)(/A`!PX(0`@?`@#IDZ``"`\8!``.&-=[$S&,8)+__`1?&D;>3A@
M``!!@@`<B`D``"^```!!G@`0:`,`,'QC`-!48P_^@`$`))!_<2!\"`.F@^$`
M'#@A`"!.@``@E"'_\'P(`J:0`0`42``4O4@`%!E\:1MY.&```$&"``B`:0``
M@`$`%#@A`!!\"`.F3H``()0A_[!\"`*F/2`0`#DI7(R3H0!$?'T;>)/A`$R0
M`0!4DR$`-)-!`#B380`\DX$`0)/!`$B`"0`D@,D`*'P?`WF`Z0`L@0D`,(%)
M`#2!:0`X@2D`/)`!`!20P0`8D.$`')$!`""100`DD6$`*)$A`"Q!@@!T/V`0
M`#^`$``[P0`4.WM=G#N<79A(```<2``3.2^#``!!G@!\A_X`!"^?``!!G@!$
M?^/[>$S&,8)+_^[Q?Z3K>'QY&WE!@@`0B!D``"^```!`OO_(?^/[>'^DZWA,
MQC&"2__S&8?^``0OGP``0)[_Q(`!`%2#(0`T?`@#IH-!`#B#80`\@X$`0(.A
M`$2#P0!(@^$`3#@A`%!.@``@?Z/K>$@`%-%\>AMX?R/+>$@`%,5\>AH4.&,`
M`D@`%$DX@``!.*#__WQZ&WA_9MMX?Z?K>'^(XWA_*<MX3,8Q@D@`%-5_X_MX
M?T33>$S&,8)+__*-2___-#P`__]\+`MX8`!^H#T@$`!\(0%N?`@"ICDI7(R3
M+/_D?'D;>).,__`_@!``D`P`!#N<77R2+/_$?X/C>)),_\B2;/_,DHS_T)*L
M_]22S/_8DNS_W),,_^"33/_HDVS_[).L__23S/_XD^S__(/I`$R`B0!0@*D`
M5(#)`%B`Z0!<@0D`8(%)`&2!:0!H@`D`;(.I`$2#R0!(@PD`0#TA``&"(H_X
MDBF!'#H@``"3`0!`D^$`*).A`$23P0!(D($`+)"A`#"0P0`TD.$`.)$!`#R1
M00!,D6$`4)`!`%1,QC&"2__M57Q_&WE!@@`0B!\``"^```!`G@182__];7QX
M&WE!@@1@B_@``"^?``!!G@`T2``5C7\)PW@Y0`!?@6,``%?_"#Q\"_HN<!,(
M`$""``B920``C^D``2^?``!`GO_@@&$`*"^#``!!G@!0.^$`*$@``!"$?P`$
M+X,``$&>`#Q,QC&"2__LT7Q^&WE!HO_HB!X``"^```!!GO_<2__P/2^#``!!
MGO_0?\/S>$@`$X%\=QMY0((`?(/A`$`ZX```+Y\``$&>`&R('P``.\```2^`
M``!`O@`\2```6#@```!7R1`Z8`"!('P`"A1]($H4/2G__X/I?R`OGP``09X!
MF(@?```[W@`!+X```$&>`8A_X_MX2__OQ2^#``!!GO_`?^/[>$@`$PE\=QMY
M08+_L'[CNW@_H!``2``293N]7:1\?QMX?P/#>$@`$E5__QH4._\$!'_C^WA(
M`!'5/,`0`#T@$`!\?AMX.(```3B@__\XQEZ8?N>[>'^HZW@Y*5ZD?PK#>$S&
M,8)(`!)5?\/S>#B``<!(`!*)+X/__T&>`+P_`!`"@'C,T$@`$\5_Q/-X.*,`
M8#A@``-(`!/%+X,``$&>`-P](!`"@-D``#R@$`"`:<S,.(```3BE7S1_Q_-X
M.^```$S&,8)(`!+%/,$``7_C^WB`YH$<@,*/^'SG,GDXP```0(((U(%A``"`
M"P`$@BO_Q'P(`Z:"2__(@FO_S(*+_]""J__4@LO_V(+K_]R#"__@@RO_Y(-+
M_^B#:__L@XO_\(.K__2#R__X@^O__'UA6WA.@``@2``1]8$#```OB``109[_
M/#T@$`*`V0``/*`0`(!IS,PX@``!.*5>K'_'\W@[X```3,8Q@D@`$B%+__]<
M.N```$O__IB`>,S02``2S8`#`'!4``0F+X!``$">_Q2`>,S02``2M8+C`'A(
M``^-?Y<8`$">_OR`>,S02``2G8`#`'!4``7^+X`!P$">_N1_X_MX2``017Q_
M&W@\8!``.&-@6$S&,8)+_^I9+X,``$&>`?"#&0``2``1(7QD&WA_`\-X2__S
M57QX&WE!@@'4?P/#>$@`$'4O@P`#?'<;>$"=`#@X8__\/(`0`'QX&A0XA%[H
M2``.12^#``!`G@`<+Y<`!$&>!FQ^^+H4B!?_^R^``"]!G@9<2__YF2^#``!`
MG@`<?P/#>#B```!,QC&"2``0.7QY&WE`@@%P/(`0`#Q@$``XA%Z,.&-=[#\@
M$`!,QC&"2__M_3]@$`!(``]-.SE@+#S`$`!\:1MX.(```7_C^W@XH/__.,9?
M$'_'\WA_J.MX?RK+>$S&,8)(``_].T```#M[7R!(``!(2``078`#```O@``1
M0)X`3$@`#OT[6@`!.(```9,A``A\:1MX.*#__W_C^WA_9MMX?\?S>'^HZWA_
M2M-X3,8Q@D@`#ZU_X_MX.(`!P$@`#^$O@___09[_K'_#\WA(``V!?X/C>'_D
M^WA,QC&"2__M27_C^WA+__E52__]A$O_^4U_X_MX2``/N7Q_&WA+__UP@&$`
M3"^#``!!G@!@.^```4@``"PZ0```5^D0.F)2@2`[_P`!?E(*%'TR2A0]*?__
M@&E_+"^#``!!G@`P3,8Q@DO_Z)5\:1MY0:+_S(@)```O@```09[_P$@`#U5\
M>!MY08+_M$O_^T`_`!``.QA>D$O_^W"#&0``2__^+#B@__\XP/_N..```D@`
M#>5_(\MX.($`6#B@``9(``R%B`$`6"^```!`G@`0B`$`62^``$-!G@4@.,``
M`'\CRW@XH```..```$@`#:D](&=%.0```&$I(P&1`0`8/,$``9$A`!P](._-
M.0```&$IJXDY0```.6```#@```#(`0`8.N```-@&@%B1`0`8.0```)$A`!P]
M()BZ82G<_L@!`!C8!H!@D0$`&#D```"1(0`</2`0,F$I5';(`0`8V`:`:)$!
M`!@Y````D2$`'#T@P])A*>'PR`$`&-@&@'"1`0`8D2$`',@!`!C8!H!XD4$`
M&)%A`!S(`0`8D`:`T-@&@(#8!H"(.*```'\CRW@X@0!88*6``$@`"XU\>!MY
M0($!H#SA``%7"!@X@2>`@'\`_G"`YX"$*XD``'T(.A1!G0`@+XD``#TA``&!
M28"(@6F`C$">`"!_AT!`0)T`&#XA``&!48"(@7&`C#%K``%]2@&45`D8.%<;
M'WX^00`!5!H??GT[VWB`<H#0.````'UKV!1]2M$4DO*`@&``@)"1$H"$+X,`
M`)%!`!@Z80!8?J$"%)%A`!S(`0`8V!*`B$&>`&@@`P!`?Q/#>'^8``!`G0`(
M?!,#>#C````X@0!88,:`D'YEFWA^H3(4?'4:%$@`"O4\X0`!@`>`T'P3`A0O
M@`!`D`>`T$">_P`X8```.0$`6&!C@%A_$\!0?&,*%'YHFA1+_\LM+Y@`/T"=
M`%P[&/_`.I,`0%<2T;Y^=IMX5D`P,GZ4`A1^Q+-X.*``0'ZCJW@ZU@!`2``*
MC3A@``!@8X!8?&,*%$O_RNE_EJ``0)[_V#@2``%64C`R5``P,G\2P%!^<P(4
M?P7#>'YDFW@XP`!(?J.K>$@`"[T](0`!.*```),)@-!_(\MX.($`6&"E@`!(
M``GQ?'@;>4&!_FA_(\MX2``-T3U!``$Y8```@VJ`A&%K@2!]:PH4@TJ`C%=E
M[KXX!0`!?2LJ%"^``#@X`/^`F`G_<$&=`A0Z8```.(```&)S@%A^<PH4?',J
M%""E`#<X8P`Y2``+_3[A``%71T8^5TB$/E=*PCZ8]X#(5VM&/E=IA#Z9%X#)
M5V#"/IE7@,HX8```FU>`RV!C@%@^(0`!F7>`S'QC"A29-X#-F!>`SIMW@,]+
M_\GI/,$``8$F@'2!!H!<@4:`9%4Z1CY5.X0^@6:`;%4'1CY5$H0^@`:`?%43
MPCY55$8^556$/E56PCZ;48$457=&/E5XA#Z;<8$557G"/E4CPCZ8\8$(5`1&
M/E0%A#Z:48$)5`;"/C]`$`":<8$*F1&!"SM@```[6E\(FI&!#)JQ@0V:T8$.
MF5&!#YKQ@1";$8$1FS&!$IEQ@1.8<8$6F3&!%YB1@1B8L8$9F-&!&I@1@1M(
M```4.F```&)S@0A](9H4?.G8KCI```!78P@\8E*`W#B```%^4@H4.*#__WQR
M&A1_1M-X3,8Q@D@`"I$OFP`3.WL``4">_\`X````/N$``9@7@00Y(```/,`0
M`&$I@-P]0!``.*#__SC&7OA_Q_-X?ZCK>'TI"A0Y2F`L.(```7_C^WA,QC&"
M2``*07_#\WA(``@I?X/C>'_D^WA,QC&"2__G\7_C^WA+__/]2__X+(,Y``0O
MF0``0;[YH'\CRWA(``G)*X,``T"]^9`X8__\/(`0`'QY&A0XA%[P2``'G2^#
M``!`OOET?SC+>$O_^6PZ(```.(```&(Q@%@Z0```?C$*%&)2@)!\<2H4(*4`
M/SAC`#E(``GE.&```&!C@%A\8PH42__($7QADA0X@```.*``.$@`"<5+__W(
MB`$`6B^``$%`GOK<B`$`6R^``$-`GOK0B`$`7"^``$A`GOK$B`$`72^``$5`
MGOJX.,#_QCC@``(XH/__?R/+>$@`"%TX@0!8?R/+>#B@`"E(``;]/,`0`#U`
M$`!_X_MX.(```3B@__\XQE[X?\?S>'^HZW@Y(0!8.4I@+$S&,8)(``D-2__Y
M=$@`!V64(?_0?`@"II,A`!0_(!`"@'G,T)`!`#23`0`0DT$`&)-A`!R3@0`@
MDZ$`))/!`"B3X0`L2``*73@```&8`P35/&`0`#AC7=!,QC&"2__B+2P#``!!
M@@`0B`,``"^``#%!G@(X2__OE8!YS-`_H!`".[W,]$@`"AT\@!``.*```3B$
M7X@XP``+2``'V2P#``!!@@#,@3T0!#O```"!8P`0+XD``8-+`!A`G0"H/V`0
M`CO@``$[>\S02```+(")`!!_@^-X2``%[8$]$`0O@P``0)X`@#O_``$[W@`!
M?XGX`$"=`'"`>P``2``)J7]$TWA_Q?-X.,```$@`"1E\>!MY08(!^($X``!7
MX!`Z@7T0"(%)``A_BP`N<4@$`$""_Z"`>P``2``);8"8```XH```.,```D@`
M!IU\9!MX?X/C>$@`!7&!/1`$+X,``$&>_X@X"?__?X#P`$&>`5"`><S0/^`0
M`D@`"2T\@!``.*```3B$7Y`XP``$2``&Z7Q^&WE!@@`T@'_,T$@`"0F!/@`0
M/*`0`#BE7Y2`B0``2``&)8$^`!"!*0``@`D`"'0)`$!`@@$P@'G,T#_`$`)(
M``C5/(`0`#B@``$XA%^<.,``!$@`!I%\?QMY08(`-#Q@$``X8UV(3,8Q@DO_
MX)%\?!MY@'[,T$&"`8A(``B9@3\`$'^%XWB`B0``2``%N8!YS-!(``B!.```
M`)@#!-6`><S02``(<3@```"0`P9,/&`0`#AC77Q,QC&"2__@02^#``"0?1`,
M09X`R#B``<!(``;U?&8;>4&"`!0OA@`109X`#"^&__]`G@&,@`$`-(,!`!!\
M"`.F@R$`%(-!`!B#80`<@X$`((.A`"2#P0`H@^$`+#@A`#!.@``@B`,``2^`
M``!!OOW(2__]P"^)``%`O?ZP/V`0`CO@``$[>\S0@'L``#O_``%(``?-?T33
M>$@`!$6`'1`$?X#X`$&=_^1+__Z`@'_,T$@`!ZV!/@`0@(D``$@`!K%+__[`
M@3T0!#@)__]_@/``0)[^6$O__Z"`?1`(2__Q-2^#``"0?1`,09X`Q($_`!"!
M*0``@`D`"'`+!`!!@@!H@&D`$("=$`A(``1E@3\`$(%]$`A\?AMX@2D``(.K
M``"`"0`(<`@$`$&"`&"`J0`0/&`0`'^DZW@X8U_$?\;S>$S&,8)(``692``'
M%8%_`!"!/1`(@&L``(")``!+_^692__^>#T@$`*`:<S02``&\8$_`!`XH```
M.,```H")``!(``0=2___@(!YS-!(``;1@3\`$#B@```XP``"@(D``$@``_U\
M91MX2___B#Q@$``X8U^@3,8Q@D@`!26!/1`(/&`0`("]$`PX8U_L@(D``$S&
M,8)(``4)E"'_X'P(`J:3P0`8?'X;>)`!`"23X0`<2__J$8@#``!\?QMX+X``
M`$&>`#PY(P`!?&L;>$@``!2,"P`!.2D``2^```!!G@`@+X``+T">_^R,"P`!
M?3]+>#DI``$O@```0)[_Z$O_[;DO@P``09X`,"^>``!!G@`HB!X``"^```!!
MG@`</(`0`'_C^W@XA%ZD2``"!7^?&`!!G@`<@`$`)(/!`!A\"`.F@^$`'#@A
M`"!.@``@@`$`)'_#\WB#X0`<@\$`&'P(`Z8X(0`@2__?J)0A_^!\"`*FD^$`
M'#_@$`*`?\S0D`$`)$@`!9TX@/__2``"]8!_S-!(``6-/(`0`#B@```XA#,X
M2``%38`!`"2#X0`<."$`('P(`Z9.@``@E"'_\'P(`J9"GP`%.,```)/!``A_
MR`*FD`$`%#_>``([WIG,@3Z``"^)``!!G@`(@,D``$@``J&``0`4@\$`"#@A
M`!!\"`.F3H``()0A_]!\"`*F0I\`!9/!`"A_R`*FDR$`%'RY*WB300`8?)HC
M>#_>``*380`<?'L;>#O>F823@0`@DZ$`))`!`#23X0`L2_^]S8.^@`2#GH``
M?YW@4'^<%G%!@@`P.[W__#O@``"$'0`$?V/;>']$TWA_)<MX._\``7P)`Z9.
M@`0A?Y_@`$">_^"``0`T@R$`%'P(`Z:#00`8@V$`'(.!`""#H0`D@\$`*(/A
M`"PX(0`P3H``($Z``""4(?_P?`@"II`!`!23X0`,/^`0`3O_;O2`'__\+X#_
M_T&>`!P[___\?`D#IDZ`!"&$'__\+X#__T">__"``0`4@^$`##@A`!!\"`.F
M3H``()0A__!\"`*FD`$`%(`!`!0X(0`0?`@#IDZ``"``````/6`0`8%K<`!]
M:0.F3H`$(#U@$`&!:W`$?6D#IDZ`!"`]8!`!@6MP"'UI`Z9.@`0@/6`0`8%K
M<`Q]:0.F3H`$(#U@$`&!:W`0?6D#IDZ`!"`]8!`!@6MP%'UI`Z9.@`0@/6`0
M`8%K<!A]:0.F3H`$(#U@$`&!:W`<?6D#IDZ`!"`]8!`!@6MP('UI`Z9.@`0@
M/6`0`8%K<"1]:0.F3H`$(#U@$`&!:W`H?6D#IDZ`!"`]8!`!@6MP+'UI`Z9.
M@`0@/6`0`8%K<#!]:0.F3H`$(#U@$`&!:W`T?6D#IDZ`!"`]8!`!@6MP.'UI
M`Z9.@`0@/6`0`8%K<#Q]:0.F3H`$(#U@$`&!:W!`?6D#IDZ`!"`]8!`!@6MP
M1'UI`Z9.@`0@/6`0`8%K<$A]:0.F3H`$(#U@$`&!:W!,?6D#IDZ`!"`]8!`!
M@6MP4'UI`Z9.@`0@/6`0`8%K<%1]:0.F3H`$(#U@$`&!:W!8?6D#IDZ`!"`]
M8!`!@6MP7'UI`Z9.@`0@/6`0`8%K<&!]:0.F3H`$(#U@$`&!:W!D?6D#IDZ`
M!"`]8!`!@6MP:'UI`Z9.@`0@/6`0`8%K<&Q]:0.F3H`$(#U@$`&!:W!P?6D#
MIDZ`!"`]8!`!@6MP='UI`Z9.@`0@/6`0`8%K<'A]:0.F3H`$(#U@$`&!:W!\
M?6D#IDZ`!"`]8!`!@6MP@'UI`Z9.@`0@/6`0`8%K<(1]:0.F3H`$(#U@$`&!
M:W"(?6D#IDZ`!"`]8!`!@6MPC'UI`Z9.@`0@/6`0`8%K<)!]:0.F3H`$(#U@
M$`&!:W"4?6D#IDZ`!"`]8!`!@6MPF'UI`Z9.@`0@/6`0`8%K<)Q]:0.F3H`$
M(#U@$`&!:W"@?6D#IDZ`!"`]8!`!@6MPI'UI`Z9.@`0@/6`0`8%K<*A]:0.F
M3H`$(#U@$`&!:W"L?6D#IDZ`!"`]8!`!@6MPL'UI`Z9.@`0@/6`0`8%K<+1]
M:0.F3H`$(#U@$`&!:W"X?6D#IDZ`!"`]8!`!@6MPO'UI`Z9.@`0@/6`0`8%K
M<,!]:0.F3H`$(#U@$`&!:W#$?6D#IDZ`!"`]8!`!@6MPR'UI`Z9.@`0@/6`0
M`8%K<,Q]:0.F3H`$(#U@$`&!:W#0?6D#IDZ`!"`]8!`!@6MPU'UI`Z9.@`0@
M/6`0`8%K<-A]:0.F3H`$(#U@$`&!:W#<?6D#IDZ`!"`]8!`!@6MPX'UI`Z9.
M@`0@/6`0`8%K<.1]:0.F3H`$(#U@$`&!:W#H?6D#IDZ`!"`]8!`!@6MP['UI
M`Z9.@`0@/6`0`8%K</!]:0.F3H`$(#U@$`&!:W#T?6D#IDZ`!"`]8!`!@6MP
M^'UI`Z9.@`0@/6`0`8%K</Q]:0.F3H`$(#U@$`&!:W$`?6D#IDZ`!"`]8!`!
M@6MQ!'UI`Z9.@`0@/6`0`8%K<0A]:0.F3H`$(#U@$`&!:W$,?6D#IDZ`!"`]
M8!`!@6MQ$'UI`Z9.@`0@2``!$$@``0Q(``$(2``!!$@``0!(``#\2```^$@`
M`/1(``#P2```[$@``.A(``#D2```X$@``-Q(``#82```U$@``-!(``#,2```
MR$@``,1(``#`2```O$@``+A(``"T2```L$@``*Q(``"H2```I$@``*!(``"<
M2```F$@``)1(``"02```C$@``(A(``"$2```@$@``'Q(``!X2```=$@``'!(
M``!L2```:$@``&1(``!@2```7$@``%A(``!42```4$@``$Q(``!(2```1$@`
M`$!(```\2```.$@``#1(```P2```+$@``"A(```D8````&````!@````8```
M`&````!@````8````&`````]@!`!/6OP`(`,;_@Y:Z40?`D#IGP+6A2!C&_\
M?6!:%$Z`!"!@````8````&````!@````8````&````!@````E"'_\'P(`J:0
M`0`4D\$`"$*?``5_R`*F/]X``3O>$Z!+_[GE@`$`%'P(`Z:#P0`(."$`$$Z`
M`"`0`DS%$``3X!``57@0`%8L``(``5]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@`````!``8#@0`&!($`!@4!``8%@0`&!@$`!@=``````0`&"`
M$`!=>``````0`%Y0$`!>5!``8(@0`%V`$`!@D``````0`&"4$`!@G`````!9
M@`````````````!!S____X```"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0
M`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`
M````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#
M2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'
M`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```%-9
M4U1%30``)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@``05)'5@`````8````<&5R;``````P````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U
M=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````+64``"TM``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(```O
M=&UP`````%1%35!$25(`5$U0`%5315(`````55-%4DY!344``````1L#.P``
M`!`````!__^U>````"@````0``````%Z4@`$?$$!&PP!`````!`````8__^U
M2````"0`````````$``````!>E(`!'Q!`1L,`0`````0````&/__]:````6@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_____`````/____\``````````!`!<1P0`6[P$`%N\`````$````!
M`````0```<\````!```"'@````P0`!.(````#1``7$!O__[U$``!J`````40
M``F0````!A```P`````*```%``````L````0````%0`````````#$`%P````
M``(```,\````%`````<````7$``03'`````0`6_T````!Q``$`0````(```#
MA`````D````,;____A``#V1O____`````F____`0``Z0````````````````
M`````````````````````````````````````````````````````!`!;Q``
M`````````!``6O`0`%KT$`!:^!``6OP0`%L`$`!;!!``6P@0`%L,$`!;$!``
M6Q00`%L8$`!;'!``6R`0`%LD$`!;*!``6RP0`%LP$`!;-!``6S@0`%L\$`!;
M0!``6T00`%M($`!;3!``6U`0`%M4$`!;6!``6UP0`%M@$`!;9!``6V@0`%ML
M$`!;<!``6W00`%MX$`!;?!``6X`0`%N$$`!;B!``6XP0`%N0$`!;E!``6Y@0
M`%N<$`!;H!``6Z00`%NH$`!;K!``6[`0`%NT$`!;N!``6[P0`%O`$`!;Q!``
M6\@0`%O,$`!;T!``6]00`%O8$`!;W!``6^`0`%OD$`!;Z!``6^P0`%OP$`!;
M]!``6_@0`%O\$`!<`````````````````/____\C(2]U<W(O8FEN+W!E<FP*
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@
M("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA
M9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@
M86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0[
M"@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E
M($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@
M<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M
M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T
M:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@
M(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@
M("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP
M;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA
M<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H
M87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T
M(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@
M(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I
M;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY
M=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W
M:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P
M+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@
M("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@
M("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L
M"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T
M96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@
M(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@
M("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@
M("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@
M(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*
M("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@
M>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=6
M7S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@
M)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q
M*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O
M<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>
M4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM
M>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*
M(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE
M9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@
M("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C
M:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@
M("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO
M9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q
M(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").
M(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R
M86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U
M:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B
M=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP
M9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P
M<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO
M=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F
M:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@
M("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@
M("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D
M;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@
M("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N
M86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@
M(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y
M.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*
M("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@
M("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@
M("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@
M("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY
M("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^
M>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@
M)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@
M9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O
M8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@
M;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@
M("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R
M97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@
M("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@
M("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I
M=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@
M("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@
M(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!
M<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE
M9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI
M8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@
M=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@
M("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O
M:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-
M($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I
M=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@
M("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A
M<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@
M("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@
M('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@
M("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@
M("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@
M("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@
M("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2![
M"B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@
M("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I
M970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@
M("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@
M("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@
M("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@
M("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]
M?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I
M('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z
M.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@
M("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@
M(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@
M("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O
M('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T
M(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE
M9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@
M(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@
M("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@
M*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F
M:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E
M:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@
M("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?
M(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@
M("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968[
M"B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@
M("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@
M("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*
M("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D
M8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@
M("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U
M;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*
M"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C
M-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN
M(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@
M("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E
M<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A
M<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G
M<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@
M("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D
M,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL
M97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I
M='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@
M("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N
M86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H
M+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@
M(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@
M("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@
M;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L
M;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@
M("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q
M*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R
M:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*
M("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U
M="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@
M("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$
M:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B
M*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@
M("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^
M<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO
M9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC
M(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*
M("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX
M7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD
M('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!
M4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD
M.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I
M92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@
M("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL
M:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@
M("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T
M7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@
M("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@
M("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C
M('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL
M('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E
M871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE
M<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER
M92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER
M92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V
M87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V
M>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L
M.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3
M<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG
M.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z
M.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V
M86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M
M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2
M.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R
M7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]
M("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P
M871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%
M35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M
M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E
M<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@
M/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@
M("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@
M("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@
M;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@
M("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@
M("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE
M+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.
M5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I
M(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M
M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE
M;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R
M971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I
M;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P
M<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*
M("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@
M("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@
M("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@
M('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@
M6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@
M("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%
M04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@
M(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]
M"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H
M92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@
M;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64[
M"@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@!'0T,Z
M("A58G5N='4O3&EN87)O(#0N-BXR+3=U8G5N='4Q*2`T+C8N,@!'0T,Z("A5
M8G5N='4O3&EN87)O(#0N-BXR+35U8G5N='4Q*2`T+C8N,@``+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`
M+FIC<@`N9V]T,@`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`
M``````````````````````````````````````````````````````````L`
M```!`````A```50```%4````#0```````````````0`````````3````!P``
M``(0``%D```!9````"````````````````0`````````(0````<````"$``!
MA````80````D```````````````$`````````#1O___V`````A```:@```&H
M```!6`````4`````````!`````0````^````"P````(0``,````#````!I``
M```&`````0````0````0````1@````,````"$``)D```"9````4`````````
M```````!`````````$YO____`````A``#I````Z0````T@````4`````````
M`@````(```!;;____@````(0``]D```/9````*`````&`````@````0`````
M````:@````0````"$``0!```$`0```!(````!0`````````$````#````'0`
M```$`````A``$$P``!!,```#/`````4````7````!`````P```!^`````0``
M``80`!.(```3B````$P```````````````0`````````A`````$````&$``3
MX```$^```$A@```````````````0`````````(H````!````!A``7$```%Q`
M````.```````````````!`````````"0`````0````(0`%QX``!<>```!#``
M``````````````@`````````F`````$````"$`!@J```8*@````4````````
M```````$`````````*8````!`````A``8+P``&"\````5```````````````
M!`````````"P`````0````,0`6[P``!N\`````@```````````````0`````
M````MP````$````#$`%N^```;O@````(```````````````$`````````+X`
M```!`````Q`!;P```&\`````!```````````````!`````````##`````0``
M``,0`6\$``!O!`````P```````````````$`````````R0````8````#$`%O
M$```;Q````#@````!@`````````$````"````-(````!`````Q`!;_```&_P
M````$```````````````!`````0```!Y`````0````,0`7````!P`````10`
M``````````````0`````````UP````$````#$`%Q%```<10``%NQ````````
M```````$`````````-T````(`````Q`!S,@``,S%```00```````````````
M!`````````#B`````0```#````````#,Q0```%0```````````````$````!
H`````0````,`````````````S1D```#K```````````````!````````
